import axios from 'axios';

const api = axios.create({
    baseURL: '/api',
    withCredentials: true, // Include cookies if needed
});

api.interceptors.request.use(
	(config) => {
			const token = sessionStorage.getItem('token') || '03d9163150a8bfbbee2a33c4444237f337a35278';
			if (token) {
					config.headers.Authorization = `Token ${token}`;
			}
			return config;
	},
	(error) => {
			console.error('Request error:', error);
			return Promise.reject(error);
	}
);

api.interceptors.response.use(
    (response) => {
        return response;
    },
    (error) => {
        return Promise.reject(error);
    }
);

const get = async (url, params) => {
    const response = await api.get(url, params);
    return response.data;
};

const post = async (url, data) => {
    const response = await api.post(url, data);
    return response.data;
};

const put = async (url, data) => {
    const response = await api.put(url, data);
    return response.data;
};

const del = async (url) => {
    const response = await api.delete(url);
    return response.data;
};	

const upload = async (url, data) => {
	const response = await api.post(url, data, {
		headers: {
			'Content-Type': 'multipart/form-data',
		},
	});
	return response.data;
};


export default { get, post, put, del, upload };
